import { setErrorByKey } from './actions';
/**
 * Creates an error state node.
 *
 * @param key - An error state key.
 * @param metaContent - An optional meta content value.
 * @param final - An optional flag which adds final with output functionality.
 * @public
 */
export const createErrorStateNode = (key, metaContent, final = true) => {
    return {
        tags: ['error', key],
        meta: {
            content: metaContent ? metaContent : `${key} error.`,
        },
        entry: [setErrorByKey(`${key}-error`)],
        /**
         * Provide final output to parent machines.
         */
        type: final ? 'final' : 'atomic',
        output: ({ context }) => ({
            error: context.error,
            data: context.error,
        }),
    };
};
